@@ -38,12 +38,12 @@ public:
         : std::runtime_error(what.toStdString()) {}
 };
 
-Device::Device()
-    : QObject()
+Device::Device(QObject *parent)
+    : QObject(parent)
 {}
 
-Device::Device(const QDBusObjectPath &path)
-    : QObject()
+Device::Device(const QDBusObjectPath &path, QObject *parent)
+    : QObject(parent)
     , mInterface(std::make_unique<DeviceInterface>(
         DBusHelper::serviceName(), path.path(), DBusHelper::connection()))
     , mDBusPath(path)
@@ -60,10 +60,10 @@ Device::Device(const QDBusObjectPath &path)
 
 Device::~Device() = default;
 
-QSharedPointer<Device> Device::create(const QDBusObjectPath &path)
+QSharedPointer<Device> Device::create(const QDBusObjectPath &path, QObject *parent)
 {
     try {
-        return QSharedPointer<Device>::create(path);
+        return QSharedPointer<Device>::create(path, parent);
     } catch (const DBusException &e) {
         qCWarning(log_libkbolt, "%s", e.what());
         return {};
